record.FtDomRecord

|  | ## Cheshire3 Object Model: Class FtDomRecord

Module record :: Class FtDomRecord

## Class FtDomRecord
source code

Object Tree:

    baseObjects.Record --+
                         |
                 DomRecord --+
                             |
                            FtDomRecord

Instance Methods

get_xml(self) Return the XML for the record as a serialised string.
process_xpath(self, tuple) Process the given xpath (either string or compiled), perhaps with some supplied namespace mappings.
Inherited from `DomRecord`: `__init__`, `get_dom`, `get_sax` Inherited from `DomRecord` (private): `_walk`

Class Variables

Inherited from `DomRecord`: `context`, `size` Inherited from `baseObjects.Record`: `baseUri`, `dom`, `elementHash`, `history`, `parent`, `processHistory`, `recordStore`, `resultSetItem`, `rights`, `sax`, `schema`, `schemaType`, `status`, `xml`

Method Details

### get_xml(self) | source code
Return the XML for the record as a serialised string. Overrides: baseObjects.Record.get_xml (inherited documentation)

### process_xpath(self, tuple) | source code
Process the given xpath (either string or compiled), perhaps with some supplied namespace mappings. Overrides: baseObjects.Record.process_xpath (inherited documentation)